@@ -15,7 +15,7 @@ pub trait Executor {
     ///
     /// Dropping the handle will cancel the future. You can call `detach()` to let it
     /// run without waiting for its completion.
-    fn spawn<T: Send>(&self, f: Pin<Box<dyn Future<Output = T> + Send>>) -> Box<dyn Task<T>>;
+    fn spawn<T: Send + 'static>(&self, f: Pin<Box<dyn Future<Output = T> + Send>>) -> Box<dyn Task<T>>;
 }
 
 /// A common interface for spawning non-Send futures on top of an executor, on the current thread
@@ -24,21 +24,21 @@ pub trait LocalExecutor {
     ///
     /// Dropping the handle will cancel the future. You can call `detach()` to let it
     /// run without waiting for its completion.
-    fn spawn_local<T>(&self, f: Pin<Box<dyn Future<Output = T>>>) -> Box<dyn Task<T>>;
+    fn spawn_local<T: 'static>(&self, f: Pin<Box<dyn Future<Output = T>>>) -> Box<dyn Task<T>>;
 }
 
 /// A common interface for spawning blocking tasks on top of an executor
 #[async_trait]
 pub trait BlockingExecutor {
     /// Convert a blocking task into a future, spawning it on a decicated thread pool
-    async fn spawn_blocking<T: Send>(&self, f: Box<dyn FnOnce() -> T + Send>) -> T;
+    async fn spawn_blocking<T: Send + 'static>(&self, f: Box<dyn FnOnce() -> T + Send>) -> T;
 }
 
 impl<E: Deref> Executor for E
 where
     E::Target: Executor,
 {
-    fn spawn<T: Send>(&self, f: Pin<Box<dyn Future<Output = T> + Send>>) -> Box<dyn Task<T>> {
+    fn spawn<T: Send + 'static>(&self, f: Pin<Box<dyn Future<Output = T> + Send>>) -> Box<dyn Task<T>> {
         self.deref().spawn(f)
     }
 }
@@ -47,7 +47,7 @@ impl<E: Deref> LocalExecutor for E
 where
     E::Target: LocalExecutor,
 {
-    fn spawn_local<T>(&self, f: Pin<Box<dyn Future<Output = T>>>) -> Box<dyn Task<T>> {
+    fn spawn_local<T: 'static>(&self, f: Pin<Box<dyn Future<Output = T>>>) -> Box<dyn Task<T>> {
         self.deref().spawn_local(f)
     }
 }
@@ -57,14 +57,14 @@ impl<E: Deref + Sync> BlockingExecutor for E
 where
     E::Target: BlockingExecutor + Sync,
 {
-    async fn spawn_blocking<T: Send>(&self, f: Box<dyn FnOnce() -> T + Send>) -> T {
+    async fn spawn_blocking<T: Send + 'static>(&self, f: Box<dyn FnOnce() -> T + Send>) -> T {
         self.deref().spawn_blocking(f).await
     }
 }
 
 /// A common interface to wait for a Task completion, let it run n the background or cancel it.
 #[async_trait]
-pub trait Task<T>: Future<Output = T> {
+pub trait Task<T: 'static>: Future<Output = T> {
     /// Let the task run in the background, discarding its return value
     fn detach(self);
     /// Cancels the task and waits for it to stop running.
